==> eiffelstudio-16.05.tar: F_code/C1/ir13.c <==
/*
 * Code for class IRON_STRING_VARIABLE_EXPANSER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir13.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_STRING_VARIABLE_EXPANSER}.expand_string_32 */
void F16_157 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(6);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,loc5);
	RTLR(3,loc6);
	RTLR(4,arg2);
	RTLR(5,Current);
	RTLIU(6);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = (EIF_INTEGER_32) loc1;
	loc4 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	for (;;) {
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 0L))) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
		}
		if (tb1) break;
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '$';
		loc1 = F2113_20965(RTCW(arg1), tw1, loc2);
		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
			loc2 = (EIF_INTEGER_32) loc1;
			loc1++;
			{
				/* INLINED CODE (item) */
				tw1 = (EIF_CHARACTER_32)  0;
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				tw1 = 
					/* INLINED CODE (SPECIAL.item) */
					*((EIF_CHARACTER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L))))
					/* END INLINED CODE */;
				/* END INLINED CODE */
			}
			tw1 = tw1;
			tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '{';
			if ((EIF_BOOLEAN)(tw1 == tw2)) {
				loc1++;
				tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '}';
				loc3 = F2113_20965(RTCW(arg1), tw1, loc1);
				loc5 = F2115_21113(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
			} else {
				{
					/* INLINED CODE (item) */
					tw1 = (EIF_CHARACTER_32)  0;
					tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
					tw1 = 
						/* INLINED CODE (SPECIAL.item) */
						*((EIF_CHARACTER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L))))
						/* END INLINED CODE */;
					/* END INLINED CODE */
				}
				tw1 = tw1;
				tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '(';
				if ((EIF_BOOLEAN)(tw1 == tw2)) {
					loc1++;
					tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ')';
					loc3 = F2113_20965(RTCW(arg1), tw1, loc1);
					loc5 = F2115_21113(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
				} else {
					tb2 = '\01';
					tw1 = F2115_21033(RTCW(arg1), loc1);
					tr1 = RTLNS(eif_new_type(1943, 0x00).id, 1943, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb3 = F1942_19008(RTCW(tr1));
					if (!tb3) {
						{
							/* INLINED CODE (item) */
							tw1 = (EIF_CHARACTER_32)  0;
							tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
							tw1 = 
								/* INLINED CODE (SPECIAL.item) */
								*((EIF_CHARACTER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L))))
								/* END INLINED CODE */;
							/* END INLINED CODE */
						}
						tw1 = tw1;
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
						tb2 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					if (tb2) {
						loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
						for (;;) {
							tb2 = '\01';
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
							if (!(EIF_BOOLEAN) (loc3 > ti4_1)) {
								tb3 = '\01';
								tw1 = F2115_21033(RTCW(arg1), loc3);
								tr1 = RTLNS(eif_new_type(1943, 0x00).id, 1943, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F1942_19016(RTCW(tr1));
								if (!tb4) {
									{
										/* INLINED CODE (item) */
										tw1 = (EIF_CHARACTER_32)  0;
										tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
										tw1 = 
											/* INLINED CODE (SPECIAL.item) */
											*((EIF_CHARACTER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L))))
											/* END INLINED CODE */;
										/* END INLINED CODE */
									}
									tw1 = tw1;
									tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(tw1 == tw2);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							loc3++;
						}
						loc3--;
						loc5 = F2115_21113(RTCW(arg1), loc1, loc3);
					} else {
						loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
						loc5 = (EIF_REFERENCE) NULL;
					}
				}
			}
			if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
				tb3 = '\0';
				if ((EIF_BOOLEAN)(loc5 != NULL)) {
					{
						static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1910,2112,0xFFFF};
						EIF_TYPE typres0;
						static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
						
						typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
						tr1 = RTLNTS(typres0.id, 2, 0);
					}
					((EIF_TYPED_VALUE *)tr1+1)->it_r = loc5;
					RTAR(tr1,loc5);
					tr1 = F2070_20337(RTCW(arg2), tr1);
					loc6 = tr1;
					tb3 = EIF_TEST(loc6);
				}
				if (tb3) {
					F2115_21043(RTCW(arg1), loc6, loc2, loc3);
					loc1 = *(EIF_INTEGER_32 *)(loc6 + O16313[Dtype(loc6)-2112]);
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + loc1);
				} else {
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
				}
			}
		}
		loc2 = (EIF_INTEGER_32) loc1;
	}
	RTLE;
}

void EIF_Minit13 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C1/ir13.c <==
/*
 * Code for class IRON_STRING_VARIABLE_EXPANSER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir13.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_STRING_VARIABLE_EXPANSER}.expand_string_32 */
void F18_155 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(6);
	RTLR(0,arg1);
	RTLR(1,loc5);
	RTLR(2,tr1);
	RTLR(3,loc6);
	RTLR(4,arg2);
	RTLR(5,Current);
	RTLIU(6);
	
	RTEAA("expand_string_32", 17, Current, 6, 2, 177);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	loc2 = (EIF_INTEGER_32) loc1;
	RTHOOK(3);
	loc4 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	for (;;) {
		RTHOOK(4);
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 0L))) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
		}
		if (tb1) break;
		RTHOOK(5);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '$';
		loc1 = F1041_8023(RTCW(arg1), tw1, loc2);
		RTHOOK(6);
		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
			RTHOOK(7);
			loc2 = (EIF_INTEGER_32) loc1;
			RTHOOK(8);
			loc1++;
			RTHOOK(9);
			tw1 = F1043_8091(RTCW(arg1), loc1);
			tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '{';
			if ((EIF_BOOLEAN)(tw1 == tw2)) {
				RTHOOK(10);
				loc1++;
				RTHOOK(11);
				tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '}';
				loc3 = F1041_8023(RTCW(arg1), tw1, loc1);
				RTHOOK(12);
				loc5 = F1043_8171(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
			} else {
				RTHOOK(13);
				tw1 = F1043_8091(RTCW(arg1), loc1);
				tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '(';
				if ((EIF_BOOLEAN)(tw1 == tw2)) {
					RTHOOK(14);
					loc1++;
					RTHOOK(15);
					tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ')';
					loc3 = F1041_8023(RTCW(arg1), tw1, loc1);
					RTHOOK(16);
					loc5 = F1043_8171(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L)));
				} else {
					RTHOOK(17);
					tb2 = '\01';
					tw1 = F1043_8091(RTCW(arg1), loc1);
					tr1 = RTLNS(eif_new_type(987, 0x00).id, 987, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb3 = F986_7552(RTCW(tr1));
					if (!tb3) {
						tw1 = F1043_8091(RTCW(arg1), loc1);
						tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
						tb2 = (EIF_BOOLEAN)(tw1 == tw2);
					}
					if (tb2) {
						RTHOOK(18);
						loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
						for (;;) {
							RTHOOK(19);
							tb2 = '\01';
							ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
							if (!(EIF_BOOLEAN) (loc3 > ti4_1)) {
								tb3 = '\01';
								tw1 = F1043_8091(RTCW(arg1), loc3);
								tr1 = RTLNS(eif_new_type(987, 0x00).id, 987, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F986_7560(RTCW(tr1));
								if (!tb4) {
									tw1 = F1043_8091(RTCW(arg1), loc3);
									tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(tw1 == tw2);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							RTHOOK(20);
							loc3++;
						}
						RTHOOK(21);
						loc3--;
						RTHOOK(22);
						loc5 = F1043_8171(RTCW(arg1), loc1, loc3);
					} else {
						RTHOOK(23);
						loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
						RTHOOK(24);
						loc5 = (EIF_REFERENCE) NULL;
					}
				}
			}
			RTHOOK(25);
			if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
				RTHOOK(26);
				tb3 = '\0';
				if ((EIF_BOOLEAN)(loc5 != NULL)) {
					{
						static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,980,1040,0xFFFF};
						EIF_TYPE typres0;
						static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
						
						typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
						tr1 = RTLNTS(typres0.id, 2, 0);
					}
					((EIF_TYPED_VALUE *)tr1+1)->it_r = loc5;
					RTAR(tr1,loc5);
					tr1 = F1030_7710(RTCW(arg2), tr1);
					loc6 = tr1;
					tb3 = EIF_TEST(loc6);
				}
				if (tb3) {
					RTHOOK(27);
					F1043_8101(RTCW(arg1), loc6, loc2, loc3);
					RTHOOK(28);
					loc1 = *(EIF_INTEGER_32 *)(loc6 + O6773[Dtype(loc6)-1040]);
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + loc1);
				} else {
					RTHOOK(29);
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
				}
			}
		}
		RTHOOK(30);
		loc2 = (EIF_INTEGER_32) loc1;
	}
	RTHOOK(31);
	RTLE;
	RTEE;
}

void EIF_Minit13 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
